---
name: Feature request
about: Normal development issue on technical matters
title: "<subject title related to the issue>"
labels: Bug
assignees: ''

---

## Context

<!--- Provide some context why is this feature needed. 
Does it build from an existing one, does it enable an implementation of some other new feature? -->

## Required steps / Implementation details

<!--- Optional field, some feature requests are simple enough so they do not need it. When needed: either provide a list of steps that are required for this feature and/or provide technical details on how this feature will be implemented. -->

## Definiton of Done

<!--- Explicitly define conditions when this feature request is considered done, so it can be reviewed and validated. -->
